<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>BandpassDialog</name>
    <message>
        <location filename="bandpassdialog.ui" line="14"/>
        <source>Alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassdialog.ui" line="28"/>
        <source>Curve gain (dB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassdialog.ui" line="57"/>
        <source>Curve ripple (0.7 = 0dB)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListDialog</name>
    <message>
        <location filename="listdialog.ui" line="17"/>
        <source>Please select an item</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="24"/>
        <source>Loudspeaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="30"/>
        <source>number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="56"/>
        <source>vendor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="73"/>
        <source>model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="115"/>
        <location filename="mainwindow.ui" line="141"/>
        <location filename="mainwindow.ui" line="167"/>
        <location filename="mainwindow.ui" line="186"/>
        <location filename="mainwindow.ui" line="212"/>
        <location filename="mainwindow.ui" line="238"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="148"/>
        <location filename="mainwindow.ui" line="454"/>
        <location filename="mainwindow.ui" line="813"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="179"/>
        <source>Vas:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="193"/>
        <location filename="mainwindow.ui" line="330"/>
        <location filename="mainwindow.ui" line="417"/>
        <location filename="mainwindow.ui" line="719"/>
        <location filename="mainwindow.ui" line="776"/>
        <source>L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="219"/>
        <source>m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="245"/>
        <source>Ohm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="264"/>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="278"/>
        <source>Sealed enclosure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="281"/>
        <source>1st order filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="284"/>
        <source>Simple, safe enclosure good for several speakers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="313"/>
        <source>Enclosure volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="368"/>
        <source>Ported enclosure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <source>2nd order filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="374"/>
        <source>Popular enclosure type to enhance bass for most speakers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="400"/>
        <source>Enclosure volume (Vb)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="437"/>
        <source>Enclosure filter resonance (Fb)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="474"/>
        <source>Enclosure quality loss factor (Ql)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="521"/>
        <location filename="mainwindow.ui" line="880"/>
        <source>Number of ports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="538"/>
        <location filename="mainwindow.ui" line="897"/>
        <source>Port diameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="555"/>
        <location filename="mainwindow.ui" line="618"/>
        <location filename="mainwindow.ui" line="658"/>
        <location filename="mainwindow.ui" line="914"/>
        <location filename="mainwindow.ui" line="957"/>
        <location filename="mainwindow.ui" line="997"/>
        <source>cm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="575"/>
        <location filename="mainwindow.ui" line="934"/>
        <source>Slot port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="595"/>
        <location filename="mainwindow.ui" line="947"/>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="638"/>
        <location filename="mainwindow.ui" line="977"/>
        <source>Port length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="670"/>
        <source>Bandpass enclosure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="673"/>
        <source>4th order filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="676"/>
        <source>Enclosure for subwoofer, mostly used in 2:1, 5:1 and 7:1 systems.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="702"/>
        <source>Sealed enclosure volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="759"/>
        <source>Ported enclosure volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="796"/>
        <source>Ported enclosure filter resonance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="833"/>
        <source>Bandpass enclosure quality loss factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1022"/>
        <source>Project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1035"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1039"/>
        <source>Ported alignments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1056"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1062"/>
        <source>Speaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1071"/>
        <source>Exports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1110"/>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1115"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1121"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1132"/>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1137"/>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1140"/>
        <source>Print the current project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1143"/>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1148"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1151"/>
        <source>Quit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1154"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1159"/>
        <location filename="mainwindow.cpp" line="1246"/>
        <source>About QSpeakers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1162"/>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1167"/>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1170"/>
        <source>New speaker parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1173"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1178"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1181"/>
        <source>Search a speaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1186"/>
        <source>Optimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1189"/>
        <source>Optimize frequency response</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1192"/>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1197"/>
        <source>Modify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1200"/>
        <source>Modify the current speaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1203"/>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1208"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1211"/>
        <source>Remove the current speaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1216"/>
        <source>Bessel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1219"/>
        <source>Linear phase and fast transient response alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1227"/>
        <source>Extended bass response with minimum ripple</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1235"/>
        <source>Boom box butterworth 4th order alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1243"/>
        <source>Super boom box butterworth 4th order alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1256"/>
        <source>Bandpass alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1264"/>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1267"/>
        <source>Undo action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1270"/>
        <source>Ctrl+U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1278"/>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1281"/>
        <source>Redo action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1284"/>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1289"/>
        <source>3D OpenScad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1294"/>
        <source>2D OpenScad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1299"/>
        <source>Curve Plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1304"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1248"/>
        <source>Zbinden M4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="108"/>
        <source>Spl:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="122"/>
        <source>dB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="134"/>
        <source>Fs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="160"/>
        <source>Qts:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="205"/>
        <source>Dia:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="231"/>
        <source>Z:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="257"/>
        <source>Vc:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1251"/>
        <source>Moderate alignment (infinite baffle)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1224"/>
        <source>Legendre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1104"/>
        <source>Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1107"/>
        <source>Open a speaker project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1118"/>
        <source>Save the current project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1126"/>
        <source>Save copy...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1129"/>
        <source>Save the current project in a copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1232"/>
        <source>Hoge BB4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1240"/>
        <source>Bullock SBB4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="59"/>
        <source>Recently opened</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="89"/>
        <source>Sealed volume frequency response</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="95"/>
        <source>Ported volume frequency response</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="101"/>
        <source>Bandpass volumes frequency response</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="197"/>
        <source>Export File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="197"/>
        <location filename="mainwindow.cpp" line="224"/>
        <source>QSpeakers project (*.qsp)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="197"/>
        <source>untitled.qsp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="216"/>
        <location filename="mainwindow.cpp" line="239"/>
        <location filename="mainwindow.cpp" line="357"/>
        <source>Project not saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="217"/>
        <location filename="mainwindow.cpp" line="240"/>
        <source>Current project has not been saved. Continue anyway?</source>
        <oldsource>The current project has not been saved. Continue anyway?</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="224"/>
        <source>Import File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="231"/>
        <location filename="mainwindow.cpp" line="249"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="231"/>
        <location filename="mainwindow.cpp" line="249"/>
        <source>Could not open project!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="358"/>
        <source>The current project has not been saved. Exit anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="622"/>
        <source>Export for Gnuplot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="622"/>
        <source>Gnuplot data (*.dat)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="647"/>
        <source>Export for 3D OpenSCAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="647"/>
        <location filename="mainwindow.cpp" line="673"/>
        <source>OpenSCAD script (*.scad)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="673"/>
        <source>Export for 2D OpenSCAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1063"/>
        <source>Removal confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1064"/>
        <source>Do you really want to remove this loudspeaker from the database?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1247"/>
        <source>QSpeakers version %1 (%2)

This program simulates common acoustical enclosures behaviour to help designing loudspeaker systems.

This program is free software, copyright (C) 2014 Benoît Rouits &lt;brouits@free.fr&gt; and released under the GNU General Public License version 3. It is delivered as is in the hope it can be useful, but with NO WARRANTY AT ALL.</source>
        <oldsource>QSpeakers version %1 (%2)

This program simulates common acoustical enclosures behaviour to help designing loudspeaker systems.

This program is free software, copyright (C) 2014 Benoit Rouits &lt;brouits@free.fr&gt; and released under the GNU General Public Lisence version 3. It is delivered as is in the hope it can be useful, but with NO WARRANTY at all.</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1382"/>
        <location filename="mainwindow.cpp" line="1439"/>
        <source>Unsaved speaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1383"/>
        <location filename="mainwindow.cpp" line="1440"/>
        <source>Speaker driver %1 is not present in the database. Do you want to insert it before to continue?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot</name>
    <message>
        <location filename="plot.cpp" line="257"/>
        <source>Frequency [Hz]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="plot.cpp" line="265"/>
        <source>Sound pressure [dB]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="plot.cpp" line="96"/>
        <location filename="plot.cpp" line="128"/>
        <location filename="plot.cpp" line="151"/>
        <source>%1 dB at %2 Hz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="propertiesdialog.ui" line="14"/>
        <source>Project Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="propertiesdialog.ui" line="20"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="propertiesdialog.ui" line="30"/>
        <source>Note</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="bandpassbox.cpp" line="177"/>
        <source>Sealed Volume: %1 L</source>
        <oldsource>Sealed Vol. %1 L</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="178"/>
        <source>Ported Volume: %1 L</source>
        <oldsource>Ported Vol. %1 L</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="181"/>
        <location filename="portedbox.cpp" line="219"/>
        <source>Port Diameter: %1 cm</source>
        <oldsource>Port Diam. %1 cm</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="186"/>
        <location filename="portedbox.cpp" line="223"/>
        <source>Port Length: %1 cm</source>
        <oldsource>Port Len. %1 cm</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="187"/>
        <location filename="portedbox.cpp" line="224"/>
        <source>Port #: %1</source>
        <oldsource>Port Num. %1</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="188"/>
        <location filename="portedbox.cpp" line="225"/>
        <source>Fb: %1 Hz</source>
        <oldsource>Fb %1 Hz</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="portedbox.cpp" line="217"/>
        <location filename="sealedbox.cpp" line="54"/>
        <source>Volume: %1 L</source>
        <oldsource>Vol. %1 L</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="183"/>
        <location filename="portedbox.cpp" line="221"/>
        <source>Slot port: %1 x %2 cm</source>
        <oldsource>Slot port %1 x %2 cm</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="system.cpp" line="91"/>
        <source>Loudspeaker(s): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="system.cpp" line="98"/>
        <source>sealed</source>
        <oldsource>Sealed</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="system.cpp" line="98"/>
        <source>ported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="system.cpp" line="98"/>
        <source>bandpass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="system.cpp" line="99"/>
        <source>Enclosure: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="46"/>
        <source>optimizing sealed box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="54"/>
        <source>applying &apos;max flat&apos; alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="67"/>
        <source>applying Bessel alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="75"/>
        <source>applying Bullock alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="82"/>
        <source>applying Keele &amp; Hoge alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="89"/>
        <source>applying Legendre alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="97"/>
        <source>applying Zbinden alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="133"/>
        <source>applying bandpass box alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main.cpp" line="40"/>
        <source>Loudspeaker enclosure computation program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="383"/>
        <source>Spl: %1 dB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="384"/>
        <source>Fs: %1 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="385"/>
        <source>Qts: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="386"/>
        <source>Vas: %1 L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="387"/>
        <source>Dia: %1 m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="388"/>
        <source>Xmax: %1 mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="389"/>
        <source>Z: %1 Ohm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="390"/>
        <source>Re: %1 Ohm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="391"/>
        <source>Vc: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScadDialog</name>
    <message>
        <location filename="scaddialog.cpp" line="20"/>
        <source>Loudspeaker margin (mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="scaddialog.cpp" line="24"/>
        <source>Wood thick (mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="scaddialog.cpp" line="28"/>
        <source>Saw thick (mm)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="searchdialog.ui" line="23"/>
        <source>Loudspeaker parameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchdialog.ui" line="36"/>
        <source>is between</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchdialog.ui" line="53"/>
        <source>and</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpeakerDialog</name>
    <message>
        <location filename="speakerdialog.ui" line="14"/>
        <source>Loudspeaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="38"/>
        <source>Vendor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="45"/>
        <source>speaker vendor name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="52"/>
        <source>Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="59"/>
        <source>speaker name or reference number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="66"/>
        <source>Fs (Hz)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="83"/>
        <source>Qts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="97"/>
        <source>Vas (L)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="114"/>
        <source>Dia cutout (m)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="131"/>
        <source>Z (Ohm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="145"/>
        <source>Sd (m²)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="159"/>
        <source>Re (Ohm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="173"/>
        <source>Le (mH)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="187"/>
        <source>Xmax (mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="201"/>
        <source>Qms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="215"/>
        <source>Qes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="229"/>
        <source>Spl (dB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="246"/>
        <source>Pe (W)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="263"/>
        <source>BL (Tm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="277"/>
        <source>Voice Coil (#)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="main.cpp" line="43"/>
        <source>Project file to work on.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
